Learn R Programming

rddi (version 0.1.1)

ddi_anlysUnit: anlysUnit node

Description

Provides information regarding whom or what the variable/nCube describes. The element may be repeated only to support multiple language expressions of the content. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_anlysUnit(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

anlysUnit is contained in nCube and var.

References

anlysUnit documentation

Examples

Run this code
ddi_anlysUnit("This variable reports election returns at the constituency level.")

Run the code above in your browser using DataLab