Learn R Programming

rddi (version 0.1.1)

ddi_cohort: cohort and its child nodes

Description

The element cohort is used when the nCube contains a limited number of categories from a particular variable, as opposed to the full range of categories. The attribute "catRef" is an IDREF to the actual category being used. The attribute "value" indicates the actual value attached to the category that is being used. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_cohort(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_range()

Details

Parent nodes

cohort is contained in dmns.

References

cohort documentation

Examples

Run this code
ddi_cohort(catRef = "CV24_1", value = "1")

Run the code above in your browser using DataLab