Learn R Programming

rddi (version 0.1.1)

ddi_concept: concept node

Description

The general subject to which the parent element may be seen as pertaining. This element serves the same purpose as the keywords and topic classification elements, but at the data description level. The "vocab" attribute is provided to indicate the controlled vocabulary, if any, used in the element, e.g., LCSH (Library of Congress Subject Headings), MeSH (Medical Subject Headings), etc. The "vocabURI" attribute specifies the location for the full controlled vocabulary. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_concept(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

concept is contained in the following elements: anlyUnit; anlysUnit; collMode; dataKind; geogCover; geogUnit; nCubeGrp; nation; resInstru; sampProc; srcOrig; timeMeth; universe; var; and varGrp.

References

concept documentation

Examples

Run this code
ddi_concept(vocab = "LCSH",
            vocabURI = "http://lcweb.loc.gov/catdir/cpso/lcco/lcco.html",
            source = "archive",
            "more experience")
 

Run the code above in your browser using DataLab