Learn R Programming

rddi (version 0.1.1)

ddi_contact: contact node

Description

Names and addresses of individuals responsible for the work. Individuals listed as contact persons will be used as resource persons regarding problems or questions raised by the user community. The URI attribute should be used to indicate a URN or URL for the homepage of the contact individual. The email attribute is used to indicate an email address for the contact individual. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_contact(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

contact is contained in the following elements: distStmt and useStmt.

References

contact documentation

Examples

Run this code
ddi_contact(affiliation = "University of Wisconson",
            email = "jsmith@...",
            "Jane Smith")

Run the code above in your browser using DataLab