Learn R Programming

rddi (version 0.1.1)

ddi_controlledVocabUsed: controlledVocabUsed and its child nodes

Description

Provides a code value, as well as a reference to the code list from which the value is taken. Note that the CodeValue can be restricted to reference an enumeration. More information on this element, especially the allowed attributes, can be found in the references.

Usage

ddi_controlledVocabUsed(...)

ddi_codeListAgencyName(...)

ddi_codeListID(...)

ddi_codeListName(...)

ddi_codeListSchemeURN(...)

ddi_codeListURN(...)

ddi_codeListVersionID(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_usage()

Details

Parent node

controlledVocabUsed is contained in docDscr.

controlledVocabUsed specific child nodes

  • ddi_codeListAgencyName() is the agency maintaining the code list.

  • ddi_codeListID() identifies the code list that the value is taken from.

  • ddi_codeListName() identifies the code list that the value is taken from with a human-readable name.

  • ddi_codeListSchemeURN() identifies the code list scheme using a URN.

  • ddi_codeListURN() identifies the code list that the value is taken from with a URN.

  • ddi_codeListVersionID() is the version of the code list. (Default value is 1.0).

References

controlledVocabUsed documentation

codeListAgencyName documentation

codeListID documentation

codeListName documentation

codeListSchemeURN documentation

codeListURN documentation

codeListVersionID documentation

Examples

Run this code
ddi_controlledVocabUsed(ddi_codeListID("TimeMethod"),
                        ddi_codeListName("Time Method"), 
                        ddi_codeListAgencyName("DDI Alliance"),
                        ddi_codeListVersionID("1.2"),
                        ddi_codeListURN("urn:ddi-cv:TimeMethod:1.2"),
                        ddi_codeListSchemeURN("
                               http://www.ddialliance.org/Specification/
                               DDI-CV/TimeMethod_1.2_Genericode1.0_DDI-CVProfile1.0.xml"),
                        ddi_usage())

Run the code above in your browser using DataLab