Learn R Programming

rddi (version 0.1.1)

ddi_dmns: dmns and its child nodes

Description

This element defines a variable as a dimension of the nCube, and should be repeated to describe each of the cube's dimensions. The attribute "rank" is used to define the coordinate order (rank="1", rank="2", etc.). The attribute "varRef" is an IDREF that points to the variable that makes up this dimension of the nCube. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_dmns(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_cohort()

Details

Parent nodes

dmns is contained in nCube.

References

dmns documentation

Examples

Run this code
ddi_dmns(rank = "1", varRef = "var01")

Run the code above in your browser using DataLab