Citation for the source document. This element encodes the bibliographic
information describing the source codebook, including title information,
statement of responsibility, production and distribution information, series
and version information, text of a preferred bibliographic citation, and
notes (if any). Information for this section should be taken directly from
the source document whenever possible. If additional information is obtained
and entered in the elements within this section, the source of this
information should be noted in the source attribute of the particular
element tag. More information on this element, especially the allowed
attributes, can be found in the references.