Learn R Programming

rddi (version 0.1.1)

ddi_embargo: embargo node

Description

Provides information on variables/nCubes which are not currently available because of policies established by the principal investigators and/or data producers. This element may be repeated to support multiple language expressions of the content.

Usage

ddi_embargo(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

embargo is contained in nCube and var.

References

embargo documentation

Examples

Run this code
ddi_embargo(event = "notBefore",
            date = "2001-09-30",
            "The data associated with this variable/nCube will not become 
            available until September 30, 2001, because of embargo provisions 
            established by the data producers.")

Run the code above in your browser using DataLab