ddi_exPostEvaluation()
# Functions that need to be wrapped in ddi_exPostEvaluation()
ddi_evaluationProcess("This dataset was evaluated using the following methods...")
ddi_evaluator(affiliation = "United Nations",
abbr = "UNSD",
role = "consultant",
"United Nations Statistical Division")
ddi_outcomes("The following steps were highly effective in increasing response
rates, and should be repeated in the next collection cycle...")
Run the code above in your browser using DataLab