Learn R Programming

rddi (version 0.1.1)

ddi_fileDscr: fileDscr and its children

Description

Information about the data file(s) that comprises a collection. This section can be repeated for collections with multiple files. More information on this element, especially the allowed attributes, can be found in the references.

Usage

ddi_fileDscr(...)

Value

A ddi_node object

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_fileTxt()

  • ddi_locMap()

  • ddi_notes()

Details

Parent node

fileDscr is contained in codeBook.

References

fileDscr documentation

Examples

Run this code
ddi_fileDscr()

Run the code above in your browser using DataLab