Learn R Programming

rddi (version 0.1.1)

ddi_fileStrc: fileStrc and its child nodes

Description

Type of file structure. The file structure is fully described in the first fileTxt within the fileDscr and then the fileStrc in subsequent fileTxt descriptions would reference the first fileStrcRef attribute rather than repeat the details. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_fileStrc(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_notes()

  • ddi_recGrp()

Details

Parent node

fileStrc is contained in fileTxt.

References

fileStrc documentation

Examples

Run this code
ddi_fileStrc()

Run the code above in your browser using DataLab