ddi_dataChck() are the types of checks and operations performed on the
data file at the file level.
ddi_dataMsng() can be used to give general information about missing
data, e.g., that missing data have been standardized across the collection,
missing data are present because of merging, etc.
ddi_fileCont() are the file contents. It is the abstract or description
of the file. A summary describing the purpose, nature, and scope of the data
file, special characteristics of its contents, major subject areas covered,
and what questions the PIs attempted to answer when they created the file.
A listing of major variables in the file is important here. In the case of
multi-file collections, this uniquely describes the contents of each file.
ddi_fileName() contains a short title that will be used to distinguish a
particular file/part from other files/parts in the data collection. The
element may be repeated to support multiple language expressions of the
content.
ddi_filePlac() indicates where the file was produced, whether at an
archive or elsewhere.
ddi_fileType() are the types of data files. These include raw data
(ASCII, EBCDIC, etc.) and software-dependent files such as SAS datasets,
SPSS export files, etc. If the data are of mixed types (e.g., ASCII and
packed decimal), state that here.
ddi_format() is the physical format of the data file: Logical record
length format, card-image format (i.e., data with multiple records per case),
delimited format, free format, etc. The element may be repeated to support
multiple language expressions of the content.
ddi_ProcStat() is the processing status of the file. Some data producers
and social science data archives employ data processing strategies that
provide for release of data and documentation at various stages of processing.