Learn R Programming

rddi (version 0.1.1)

ddi_imputation: imputation node

Description

According to the Statistical Terminology glossary maintained by the National Science Foundation, this is "the process by which one estimates missing values for items that a survey respondent failed to provide," and if applicable in this context, it refers to the type of procedure used. When applied to an nCube, imputation takes into consideration all of the dimensions that are part of that nCube. This element may be repeated to support multiple language expressions of the content. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_imputation(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

imputation is contained in nCube and var.

References

imputation documentation

Examples

Run this code
ddi_imputation("This variable contains values that were derived by substitution.")

Run the code above in your browser using DataLab