Learn R Programming

rddi (version 0.1.1)

ddi_labl: labl node

Description

A short description of the parent element. In the variable label, the length of this phrase may depend on the statistical analysis system used (e.g., some versions of SAS permit 40-character labels, while some versions of SPSS permit 120 characters), although the DDI itself imposes no restrictions on the number of characters allowed. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_labl(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

labl is contained in the following elements: catgry; catgryGrp; nCube; nCubeGrp; otherMat; recGrp; sampleFrame; var; and varGrp.

References

labl documentation

Examples

Run this code
ddi_labl(level = "variable", lang = "en", "short variable description")
 

Run the code above in your browser using DataLab