Learn R Programming

rddi (version 0.1.1)

ddi_locMap: locMap and its child nodes

Description

This element maps individual data entries to one or more physical storage locations. It is used to describe the physical location of aggregate/tabular data in cases where the nCube model is employed. More information on these elements, especially their allowed attributes, can be found in the references.

Parent nodes

Usage

ddi_locMap(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_dataItem()

Details

locMap is contained in fileDscr.

References

locMap documentation

Examples

Run this code
ddi_locMap()

Run the code above in your browser using DataLab