mrow or Mathematical Row is a wrapper containing the presentation expression
mi. It creates a single string without spaces consisting of the individual
elements described within it. It can be used to create a single variable by
concatenating other variables into a single string. It is used to create
linking variables composed of multiple non-contiguous parts, or to define
unique strings for various category values of a single variable. More
information on these elements, especially their allowed attributes, can be
found in the references.