Learn R Programming

rddi (version 0.1.1)

ddi_nCube: nCube and its child nodes

Description

Describes the logical structure of an n-dimensional array, in which each coordinate intersects with every other dimension at a single point. The nCube has been designed for use in the markup of aggregate data. Repetition of the following elements is provided to support multi-language content: anlysUnit, embargo, imputation, purpose, respUnit, and security. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_nCube(...)

ddi_measure(...)

ddi_purpose(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_anlysUnit()

  • ddi_embargo()

  • ddi_imputation()

  • ddi_labl()

  • ddi_location()

  • ddi_notes()

  • ddi_respUnit()

  • ddi_security()

  • ddi_txt()

  • ddi_universe()

  • ddi_verStmt()

Details

Parent nodes

nCube is contained in dataDscr.

nCube specific child nodes

  • ddi_measure() indicates the measurement features of the cell content: type of aggregation used, measurement unit, and measurement scale. An origin point is recorded for anchored scales, to be used in determining relative movement along the scale. Additivity indicates whether an aggregate is a stock (like the population at a given point in time) or a flow (like the number of births or deaths over a certain period of time). The non-additive flag is to be used for measures that for logical reasons cannot be aggregated to a higher level - for instance, data that only make sense at a certain level of aggregation, like a classification. Two nCubes may be identical except for their measure - for example, a count of persons by age and percent of persons by age. Measure is an empty element.

  • ddi_purpose() explains the purpose for which a particular nCube was created.

References

nCube documentation

measure documentation

purpose documentation

Examples

Run this code
ddi_nCube()

# Functions that need to be wrapped in ddi_nCube()

ddi_measure(aggrMeth = "sum", additivity = "stock")

ddi_purpose("Meets reporting requirements for the Federal Reserve Board")

Run the code above in your browser using DataLab