Learn R Programming

rddi (version 0.1.1)

ddi_otherMat: otherMat and its children

Description

This section allows for the inclusion of other materials that are related to the study as identified and labeled by the DTD/Schema users (encoders). The materials may be entered as PCDATA (ASCII text) directly into the document (through use of the "txt" element). This section may also serve as a "container" for other electronic materials such as setup files by providing a brief description of the study-related materials accompanied by the attributes "type" and "level" defining the material further. Other Study-Related Materials may include: questionnaires, coding notes, SPSS/SAS/Stata setup files (and others), user manuals, continuity guides, sample computer software programs, glossaries of terms, interviewer/project instructions, maps, database schema, data dictionaries, show cards, coding information, interview schedules, missing values information, frequency files, variable maps, etc. More information on this element, especially the allowed attributes, can be found in the references.

Usage

ddi_otherMat(...)

Value

A ddi_node object

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_citation()

  • ddi_labl()

  • ddi_notes()

  • ddi_otherMat()

  • ddi_table()

  • ddi_txt()

Details

Parent nodes

otherMat is contained in the following elements: codeBook and otherMat.

References

otherMat documentation

Examples

Run this code
ddi_otherMat()

Run the code above in your browser using DataLab