ddi_othrStdyMat()
# Functions that need to be wrapped in ddi_othrStdyMat()
ddi_othRefs("Part II of the documentation, the Field Representative's Manual,
is provided in hardcopy form only.")
ddi_relMat("Full details on the research design and procedures, sampling
methodology, content areas, and questionnaire design, as well as
percentage distributions by respondent's sex, race, region, college
plans, and drug use, appear in the annual ISR volumes MONITORING
THE FUTURE: QUESTIONNAIRE RESPONSES FROM THE NATION'S HIGH SCHOOL
SENIORS.")
ddi_relPubl("Economic Behavior Program Staff. SURVEYS OF CONSUMER FINANCES.
Annual volumes 1960 through 1970. Ann Arbor, MI: Institute for
Social Research.")
ddi_relStdy("ICPSR distributes a companion study to this collection titled
FEMALE LABOR FORCE PARTICIPATION AND MARITAL INSTABILITY, 1980:
[UNITED STATES] (ICPSR 9199).")
Run the code above in your browser using DataLab