0-dimensional geometric primitive, representing a position, but not having
extent. In this declaration, point is limited to a longitude/latitude
coordinate system.
Usage
ddi_point(...)
ddi_gringLat(...)
ddi_gringLon(...)
Value
A ddi_node object.
Arguments
...
Child nodes or attributes.
Details
Parent nodes
point is contained in polygon.
point specific child nodes
ddi_gringLat() is the latitude (y coordinate) of a point. Valid range
expressed in decimal degrees is as follows: -90,0 to 90,0 degrees (latitude).
ddi_gringLon() is the longitude (x coordinate) of a point. Valid range
expressed in decimal degrees is as follows: -180,0 to 180,0 degrees (longitude).