Learn R Programming

rddi (version 0.1.1)

ddi_polygon: polygon and its child nodes

Description

The minimum polygon that covers a geographical area, and is delimited by at least 4 points (3 sides), in which the last point coincides with the first point.More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_polygon(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_point()

Details

Parent nodes

polygon is contained in boundPoly.

References

polygon documentation

Examples

Run this code
# ddi_polygon requires ddi_point() which requires ddi_gringLat() and ddi_gringLon()
ddi_polygon(ddi_point(
               ddi_gringLat("42.002207"), 
               ddi_gringLon("-120.005729004")
             )
           )
           

Run the code above in your browser using DataLab