Parent nodes
prodStmt is contained in the following elements: citation; docSrc;
fileCitation; and sourceCitation.
prdStmt specific child nodes
ddi_copyright() is the copyright statement for the work at the appropriate
level. Copyright for data collection (codeBook/stdyDscr/citation/prodStmt/copyright)
maps to Dublin Core Rights. Inclusion of this element is recommended.
ddi_fundAg() is the source(s) of funds for production of the work. If
different funding agencies sponsored different stages of the production
process, use the "role" attribute to distinguish them.
ddi_grantNo() is the grant/contract number of the project that sponsored
the effort. If more than one, indicate the appropriate agency using the
"agency" attribute. If different funding agencies sponsored different stages
of the production process, use the "role" attribute to distinguish the grant
numbers.
ddi_prodDate() is the date when the marked-up document/marked-up document
source/data collection/other material(s) were produced (not distributed or
archived). The ISO standard for dates (YYYY-MM-DD) is recommended for use
with the date attribute. Production date for data collection
(codeBook/stdyDscr/citation/prodStmt/prodDate) maps to Dublin Core Date element.
ddi_prodPlac() is the address of the archive or organization that produced
the work.
ddi_software() is the software used to produce the work. A "version"
attribute permits specification of the software version number. The
"date" attribute is provided to enable specification of the date (if any)
for the software release. The ISO standard for dates (YYYY-MM-DD) is
recommended for use with the date attribute.