The producer is the person or organization with the financial or
administrative responsibility for the physical processes whereby the
document was brought into existence. Use the "role" attribute to distinguish
different stages of involvement in the production process, such as original
producer. Producer of data collection
(codeBook/stdyDscr/citation/prodStmt/producer) maps to Dublin Core Publisher
element. The "producer" in the Document Description should be the agency or
person that prepared the marked-up document. More information on this
element, especially its allowed attributes, can be found in the references.
Usage
ddi_producer(...)
Value
A ddi_node object.
Arguments
...
Child nodes or attributes.
Details
Parent nodes
producer is contained in the following elements: prodStmt and standard.