ddi_qstn("When you get together with your friends, would you say you discuss
political matters frequently, occasionally, or never", ID = "Q125")
# Functions that need to be wrapped in ddi_qstn()
# Including ddi_preQTxt within a ddi_qstn with content
ddi_qstn("When you get together with your friends, would you say you discuss
political matters frequently, occasionally, or never", ID = "Q125",
ddi_preQTxt("For those who did not go away on a holiday of four days or more in 1985..."))
ddi_qstn(ddi_postQTxt("The next set of questions will ask about your financial situation"))
# Using IDREFS in ddi_backward() and ddi_forward()
ddi_backward(qstn = "Q143")
ddi_forward("If yes, please ask questions 120-124", qstn = "Q120 Q121 Q122 Q123 Q124")
# Other child elements
ddi_ivuInstr("Please prompt the respondent if they are reticent to answer this question.",
lang = "en")
ddi_qstnLit("Why didn't you go away in 1985?")
Run the code above in your browser using DataLab