Learn R Programming

rddi (version 0.1.1)

ddi_qualityStatement: qualityStatement and its child nodes

Description

The Quality Statement consists of two parts, standardsCompliance and otherQualityStatement. In standardsCompliance list all specific standards complied with during the execution of this study. Note the standard name and producer and how the study complied with the standard. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_qualityStatement(...)

ddi_otherQualityStatement(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_standardsCompliance()

Details

Parent nodes

qualiyStatement is contained in stdyInfo.

qualityStatement specific child nodes

  • ddi_otherQualityStatement() holds additional quality statements.

References

qualityStatement documentation

otherQualityStatement documentation

Examples

Run this code
ddi_qualityStatement()

# Functions that need to be wrapped in ddi_qualityStatement()

ddi_otherQualityStatement("Additional quality statements not addressed in standardsCompliance.")

Run the code above in your browser using DataLab