Learn R Programming

rddi (version 0.1.1)

ddi_recGrp: recGrp and its child nodes

Description

Used to describe record groupings if the file is hierarchical or relational. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_recGrp(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_labl()

  • ddi_recDimnsn()

Details

Parent nodes

recGrp is contained in fileStrc.

References

recGrp documentation

Examples

Run this code
ddi_recGrp()

Run the code above in your browser using DataLab