Parent nodes
rspStmt is contained in the following elements: citation; docSrc;
fileCitation; and sourceCitation.
rspStmt specific child nodes
ddi_AuthEnty() is the person, corporate body, or agency responsible for the
work's substantive and intellectual content. Repeat the element for each author,
and use "affiliation" attribute if available. Invert first and last name and
use commas. Author of data collection (codeBook/stdyDscr/citation/rspStmt/AuthEnty)
maps to Dublin Core Creator element. Inclusion of this element in codebook is recommended.
The "author" in the Document Description should be the individual(s) or
organization(s) directly responsible for the intellectual content of the DDI
version, as distinct from the person(s) or organization(s) responsible for the
intellectual content of the earlier paper or electronic edition from which the
DDI edition may have been derived.
ddi_othId() are the statements of responsibility not recorded in the title
and statement of responsibility areas. Indicate here the persons or bodies
connected with the work, or significant persons or bodies connected with
previous editions and not already named in the description. For example, the
name of the person who edited the marked-up documentation might be cited in
codeBook/docDscr/rspStmt/othId, using the "role" and "affiliation" attributes.
Other identifications/acknowledgments for data collection
(codeBook/stdyDscr/citation/rspStmt/othId) maps to Dublin Core Contributor element.