Series statement for the work at the appropriate level: marked-up document;
marked-up document source; study; study description, other material; other
material for study. More information on these elements, especially their
allowed attributes, can be found in the references.
Usage
ddi_serStmt(...)
ddi_serInfo(...)
ddi_serName(...)
Value
A ddi_node object.
Arguments
...
Child nodes or attributes.
Details
Parent nodes
serStmt is contained in the following elements: citation; docSrc;
fileCitation; and sourceCitation.
serStmt specific child nodes
ddi_serInfo() is the series information. This element contains a history of
the series and a summary of those features that apply to the series as a whole.
ddi_serName() is the name of the series to which the work belongs.