Learn R Programming

rddi (version 0.1.1)

ddi_sources: sources and its child nodes

Description

Description of sources used for the data collection. The element is nestable so that the sources statement might encompass a series of discrete source statements, each of which could contain the facts about an individual source. This element maps to Dublin Core Source element. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_sources(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_dataSrc()

  • ddi_sourceCitation()

  • ddi_sources()

  • ddi_srcChar()

  • ddi_srcDocu()

  • ddi_srcOrig()

Details

Parent nodes

sources is contained in the following elements: dataColl and sources.

References

sources documentation

Examples

Run this code
ddi_sources()

Run the code above in your browser using DataLab