Learn R Programming

rddi (version 0.1.1)

ddi_standard: standard and its child nodes

Description

Standard describes a standard with which the study complies. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_standard(...)

ddi_standardName(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_producer()

Details

Parent nodes

standard is contained in standardsCompliance.

standard specific child nodes

  • ddi_standardName() contains the name of the standard with which the study complies.

References

standard documentation

standardName documentation

Examples

Run this code
ddi_standard()

# Functions that need to be wrapped in ddi_standard()

ddi_standardName(date = "2009-10-18",
                 version = "3.1",
                 URI = "http://www.ddialliance.org/Specification/DDI-Lifecycle/3.1/",
                 "Data Documentation Initiative")

Run the code above in your browser using DataLab