Learn R Programming

rddi (version 0.1.1)

ddi_stdyDscr: stdyDscr and its children

Description

All DDI codebooks must have a study description which contains information about the study overall. The Study Description consists of information about the data collection, study, or compilation that the DDI-compliant documentation file describes. This section includes information about how the study should be cited, who collected or compiled the data, who distributes the data, keywords about the content of the data, summary (abstract) of the content of the data, data collection methods and processing, etc. At least one citation must be present, capturing the whole study. More information on this element, especially the allowed attributes, can be found in the references.

Usage

ddi_stdyDscr(...)

Value

A ddi_node object

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_citation()

  • ddi_dataAccs()

  • ddi_method()

  • ddi_notes()

  • ddi_othrStdyMat()

  • ddi_stdyInfo()

  • ddi_studyAuthorization()

  • ddi_studyDevelopment()

Details

Parent node

stdyDscr is contained in codeBook.

References

stdyDscr documentation

Examples

Run this code
# ddi_citation() is required in ddi_stdyDscr()
ddi_stdyDscr(ddi_citation())

Run the code above in your browser using DataLab