ddi_anlyUnit() is the basic unit of analysis or observation that the file
describes: individuals, families/households, groups,
institutions/organizations, administrative units, etc.
ddi_collDate() contains the date(s) when the data were collected. Maps to
Dublin Core Coverage element. Inclusion of this element in the codebook is
recommended.
ddi_dataKind() is the type of data included in the file: survey data,
census/enumeration data, aggregate data, clinical data, event/transaction
data, program source code, machine-readable text, administrative records
data, experimental data, psychological test, textual data, coded textual,
coded documents, time budget diaries, observation data/ratings,
process-produced data, etc. This element maps to Dublin Core Type element.
ddi_geogCover() is information on the geographic coverage of the data.
Includes the total geographic scope of the data, and any additional levels
of geographic coding provided in the variables. Maps to Dublin Core Coverage
element.
ddi_geogUnit() is the lowest level of geographic aggregation covered by
the data.
ddi_nation() indicates the country or countries covered in the file.
Attribute "abbr" may be used to list common abbreviations; use of ISO country
codes is recommended. Maps to Dublin Core Coverage element. Inclusion of
this element is recommended.
ddi_timePrd() is the time period to which the data refer. This item
reflects the time period covered by the data, not the dates of coding or
making documents machine-readable or the dates the data were collected. Also
known as span. Maps to Dublin Core Coverage element. Inclusion of this
element is recommended.