Learn R Programming

rddi (version 0.1.1)

ddi_titlStmt: titlStmt and its child nodes

Description

Title statement for the work at the appropriate level: marked-up document; marked-up document source; study; study description, other materials; other materials for the study. Both titlStmt and titl are required elements in the citation branch of a DDI-Codebook. More information on these elements, especially their allowed attributes, can be found in the references.

Usage

ddi_titlStmt(...)

ddi_altTitl(...)

ddi_IDNo(...)

ddi_parTitl(...)

ddi_subTitl(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Shared and complex child nodes

  • ddi_titl()

Details

Parent nodes

titlStmt is contained in the following elements: citation; docSrc; fileCitation; and sourceCitation.

titlStmt specific child nodes

ddi_altTitl() is the alternative title. A title by which the work is commonly referred, or an abbreviation of the title.

ddi_IDNo() is the identification number. This is a unique string or number (producer's or archive's number). Can be a DOI. An "agency" attribute is supplied. Identification Number of data collection maps to Dublin Core Identifier element.

ddi_parTitl() is the parallel title. Title translated into another language.

ddi_subTitl() is the subtitle. A secondary title used to amplify or state certain limitations on the main title. It may repeat information already in the main title.

References

titlStmt documentation

altTitl documentation

IDNo documentation

parTitl documentation

subTitl documentation

Examples

Run this code
ddi_titlStmt()

# Functions that need to be wrapped in ddi_titlStmt()

ddi_altTitl("Alternative Title of work")

ddi_IDNo(agency = "agency name", "ID number")

ddi_parTitl(lang = "fr", "French translation of the title")

ddi_subTitl("Subtitle of work")

Run the code above in your browser using DataLab