Learn R Programming

rddi (version 0.1.1)

ddi_universe: universe node

Description

The group of persons or other elements that are the object of research and to which any analytic results refer. Age, nationality, and residence commonly help to delineate a given universe, but any of a number of factors may be involved, such as sex, race, income, veteran status, criminal convictions, etc. The universe may consist of elements other than persons, such as housing units, court cases, deaths, countries, etc. In general, it should be possible to tell from the description of the universe whether a given individual or element (hypothetical or real) is a member of the population under study. More information on this element, especially its allowed attributes, can be found in the references.

Usage

ddi_universe(...)

Value

A ddi_node object.

Arguments

...

Child nodes or attributes.

Details

Parent nodes

universe is contained in the following elements: nCube; nCubeGrp; sampleFrame; sumDscr; var; and varGrp.

References

universe documentation

Examples

Run this code
ddi_universe(clusion = "I", "Individuals 15-19 years of age.")

Run the code above in your browser using DataLab