A group of variables that may share a common subject, arise from the
interpretation of a single question, or are linked by some other factor.
Variable groups are created this way in order to permit variables to belong
to multiple groups, including multiple subject groups such as a group of
variables on sex and income, or to a subject and a multiple response group,
without causing overlapping groups. Variables that are linked by use of the
same question need not be identified by a Variable Group element because they
are linked by a common unique question identifier in the Variable element.
Note that as a result of the strict sequencing required by XML, all Variable
Groups must be marked up before the Variable element is opened. That is, the
mark-up author cannot mark up a Variable Group, then mark up its constituent
variables, then mark up another Variable Group. More information on these
elements, especially their allowed attributes, can be found in the
references.