The element cohort is used when the nCube contains a limited number of
categories from a particular variable, as opposed to the full range of
categories. The attribute "catRef" is an IDREF to the actual category
being used. The attribute "value" indicates the actual value attached to
the category that is being used. More information on these elements,
especially their allowed attributes, can be found in the references.