This element defines a variable as a dimension of the nCube, and should be
repeated to describe each of the cube's dimensions. The attribute "rank" is
used to define the coordinate order (rank="1", rank="2", etc.). The attribute
"varRef" is an IDREF that points to the variable that makes up this dimension
of the nCube. More information on these elements, especially their allowed
attributes, can be found in the references.