powered by
Information about the data file(s) that comprises a collection. This section can be repeated for collections with multiple files. More information on this element, especially the allowed attributes, can be found in the references.
ddi_fileDscr(...)
A ddi_node object
Child nodes or attributes.
ddi_fileTxt()
ddi_locMap()
ddi_notes()
Parent node
fileDscr is contained in codeBook.
fileDscr
codeBook
fileDscr documentation
ddi_fileDscr()
Run the code above in your browser using DataLab