Type of file structure. The file structure is fully described in the first
fileTxt within the fileDscr and then the fileStrc in subsequent
fileTxt descriptions would reference the first fileStrcRef attribute rather
than repeat the details. More information on these elements, especially
their allowed attributes, can be found in the references.