This element maps individual data entries to one or more physical storage
locations. It is used to describe the physical location of aggregate/tabular
data in cases where the nCube model is employed. More information on these
elements, especially their allowed attributes, can be found in the references.
Parent nodes