ddi_qualityStatement: qualityStatement and its child nodes
Description
The Quality Statement consists of two parts, standardsCompliance and
otherQualityStatement. In standardsCompliance list all specific standards
complied with during the execution of this study. Note the standard name and
producer and how the study complied with the standard. More information on
these elements, especially their allowed attributes, can be found in the
references.
ddi_qualityStatement()
# Functions that need to be wrapped in ddi_qualityStatement()ddi_otherQualityStatement("Additional quality statements not addressed in standardsCompliance.")