powered by
Used to describe record groupings if the file is hierarchical or relational. More information on these elements, especially their allowed attributes, can be found in the references.
ddi_recGrp(...)
A ddi_node object.
Child nodes or attributes.
ddi_labl()
ddi_recDimnsn()
Parent nodes
recGrp is contained in fileStrc.
recGrp
fileStrc
recGrp documentation
ddi_recGrp()
Run the code above in your browser using DataLab