Description of sources used for the data collection. The element is nestable
so that the sources statement might encompass a series of discrete source
statements, each of which could contain the facts about an individual source.
This element maps to Dublin Core Source element. More information on this
element, especially its allowed attributes, can be found in the references.