titl is the full authoritative title for the work at the appropriate level:
marked-up document; marked-up document source; study; other material(s)
related to study description; other material(s) related to study. The study
title will in most cases be identical to the title for the marked-up document.
'A full title should indicate the geographic scope of the data collection as
well as the time period covered. Title of data collection
'(codeBook/stdyDscr/citation/titlStmt/titl) maps to Dublin Core Title element.
This element is required in the Study Description citation. More information
on this element, especially its allowed attributes, can be found in the
references.
Usage
ddi_titl(...)
Value
A ddi_node object.
Arguments
...
Child nodes or attributes.
Details
Parent nodes
titl is contained in the following elements: table and titlStmt.