Parent nodes
titlStmt is contained in the following elements: citation; docSrc;
fileCitation; and sourceCitation.
titlStmt specific child nodes
ddi_altTitl() is the alternative title. A title by which the work is commonly referred, or an
abbreviation of the title.
ddi_IDNo() is the identification number. This is a unique string or number (producer's or
archive's number). Can be a DOI. An "agency" attribute is supplied. Identification Number
of data collection maps to Dublin Core Identifier element.
ddi_parTitl() is the parallel title. Title translated into another language.
ddi_subTitl() is the subtitle. A secondary title used to amplify or state certain limitations
on the main title. It may repeat information already in the main title.